This a state-year panel in which the Correlates of War state system is the population of interest. They are matched, as well as one can, with their corollaries in the Gleditsch-Ward system. Its primary use is merging in data demarcated in Gleditsch-Ward state system codes when the primary system in use is the Correlates of War system.
cw_gw_panelA data frame with the following 6 variables.
stateabbthe state abbreviation, which was the greatest source of agreement between both data sets
yeara numeric vector for the year
gwcodea Gleditsch-Ward state code
ccodea Correlates of War state code
gw_statenamethe state name as it appears in the Gleditsch-Ward data.
cw_statenamethe state name as it appears in the Correlates of War data.
The data-raw/ directory on Github contains more information about how
these data were created. The code itself is derived from what peacesciencer
did for its cow_gw_years data. It amounts to the creation of daily data for
both systems before doing a "full join" on where there is the least friction:
state abbreviations. This at least requires the least amount of clean-up.
Use of these data will merge only on the state code and year. The state abbreviations and state names are there for background information, where necessary/appropriate.
peacesciencer's documentation cautions that the differences between the two systems are obvious, if often overstated. Merging one into the other, where possible, will be unproblematic in almost all cases. The biggest headaches concern German unification, Yemeni unification, and the overall history of Serbia/Yugoslavia.
str(cw_gw_panel)
head(cw_gw_panel)
Run the code above in your browser using DataLab