state_panel: Create a Panel of State-Years from the Correlates of War or Gleditsch-Ward system.
Description
state_panel() is a function to create a panel of state-years
from one of two major state systems in international relations scholarship.
Usage
state_panel(system = "cow", mry = TRUE)
Value
state_panel() returns a data frame of state years corresponding with
either the Correlates of War or the Gleditsch-Ward system.
Arguments
system
a state system (either "cow" or "gw")
mry
logical, defaults to TRUE. If TRUE, the panel created extends to
the most recently concluded calendar year. If FALSE, the panel created ends
at the year of last update. See details section for more.
Details
This function leans on cw_system and gw_system in this package.
The Correlates of War system's last year is 2016. The Gleditsch-Ward system's
last year is 2020. This information matters for the mry argument in the
function.